# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator (autorest: 3.8.3, generator: @autorest/python@5.11.2)
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._affinda_api_operations import AffindaAPIOperationsMixin

__all__ = [
    "AffindaAPIOperationsMixin",
]



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator (autorest: 3.8.3, generator: @autorest/python@5.11.2)
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

try:
    from ._models_py3 import Accreditation
    from ._models_py3 import Annotation
    from ._models_py3 import Components11Zi81FSchemasInvoicedataPropertiesBankswiftAllof2
    from ._models_py3 import Components14Dm0XSchemasInvoicedataPropertiesBankaccountnumberAllof2
    from ._models_py3 import Components14V23KqSchemasInvoicedataPropertiesPaymentamountdueAllof2
    from ._models_py3 import (
        Components159Ji55SchemasResumesearchdetailPropertiesLanguagesPropertiesValueItemsAllof1,
    )
    from ._models_py3 import Components15Ayv0YSchemasInvoicedataPropertiesPaymentamounttotalAllof2
    from ._models_py3 import Components179Pdz6SchemasInvoicedataPropertiesSupplierwebsiteAllof2
    from ._models_py3 import Components17Ashz6SchemasInvoicePropertiesMetaAllof1
    from ._models_py3 import Components1Bh8NlbSchemasInvoicedataPropertiesBpaybillercodeAllof2
    from ._models_py3 import Components1ByjheSchemasInvoicedataPropertiesSupplierfaxAllof2
    from ._models_py3 import Components1Fdmi0OSchemasInvoicedataPropertiesSuppliervatAllof2
    from ._models_py3 import Components1LdfgdeSchemasInvoicedataPropertiesPaymentamountpaidAllof2
    from ._models_py3 import Components1O4BmpySchemasInvoicedataPropertiesSuppliercompanynameAllof2
    from ._models_py3 import Components1OmsnpSchemasInvoicedataPropertiesBpayreferenceAllof2
    from ._models_py3 import Components1Rbm6P1SchemasInvoicedataPropertiesBanksortcodeAllof2
    from ._models_py3 import (
        Components1TryetgSchemasResumedataPropertiesWorkexperienceItemsPropertiesOccupationPropertiesClassification,
    )
    from ._models_py3 import Components1Wx56HlSchemasInvoicedataPropertiesPaymentreferenceAllof2
    from ._models_py3 import Components2Hu973SchemasInvoicedataPropertiesCustomernumberAllof2
    from ._models_py3 import (
        Components55Nj82SchemasInvoicedataPropertiesInvoicepurchaseordernumberAllof2,
    )
    from ._models_py3 import Components5PwavySchemasInvoicedataPropertiesCustomeremailAllof2
    from ._models_py3 import Components6DhvidSchemasInvoicedataPropertiesCustomercompanynameAllof2
    from ._models_py3 import Components7CqvqpSchemasInvoicedataPropertiesInvoicenumberAllof2
    from ._models_py3 import ComponentsBvthtoSchemasInvoicedataPropertiesSupplierphonenumberAllof2
    from ._models_py3 import ComponentsE6Bjv3SchemasInvoicedataPropertiesBankibanAllof2
    from ._models_py3 import (
        ComponentsH65QjbSchemasResumesearchdetailPropertiesSkillsPropertiesValueItemsAllof1,
    )
    from ._models_py3 import (
        ComponentsK7P1F5SchemasResumesearchdetailPropertiesOccupationgroupPropertiesValueItemsAllof1,
    )
    from ._models_py3 import (
        ComponentsN9ShogSchemasResumesearchdetailPropertiesLocationPropertiesValueAllof1,
    )
    from ._models_py3 import ComponentsPs8Uo7SchemasInvoicedataPropertiesCustomerphonenumberAllof2
    from ._models_py3 import (
        ComponentsRft7JdSchemasInvoicedataPropertiesCustomerbusinessnumberAllof2,
    )
    from ._models_py3 import ComponentsRsi73USchemasInvoicedataPropertiesCustomervatAllof2
    from ._models_py3 import (
        ComponentsSxu0N3SchemasResumesearchdetailPropertiesEducationPropertiesValueItemsAllof1,
    )
    from ._models_py3 import ComponentsTz04ToSchemasInvoicedataPropertiesPaymentamountbaseAllof2
    from ._models_py3 import ComponentsUilt2MSchemasInvoicedataPropertiesBankbsbAllof2
    from ._models_py3 import ComponentsVyrnzuSchemasInvoicedataPropertiesSupplieremailAllof2
    from ._models_py3 import ComponentsWywi9WSchemasInvoicedataPropertiesCustomercontactnameAllof2
    from ._models_py3 import ComponentsY49P83SchemasInvoicedataPropertiesPaymentamounttaxAllof2
    from ._models_py3 import (
        ComponentsYe0TzySchemasInvoicedataPropertiesSupplierbusinessnumberAllof2,
    )
    from ._models_py3 import DateAnnotation
    from ._models_py3 import Education
    from ._models_py3 import EducationDates
    from ._models_py3 import Error
    from ._models_py3 import ExpectedRemunerationAnnotation
    from ._models_py3 import ExpectedRemunerationAnnotationParsed
    from ._models_py3 import Get200ApplicationJsonPropertiesItemsItem
    from ._models_py3 import GetAllDocumentsResults
    from ._models_py3 import GetAllInvoicesResults
    from ._models_py3 import GetAllJobDescriptionsResults
    from ._models_py3 import Invoice
    from ._models_py3 import InvoiceData
    from ._models_py3 import InvoiceDataBankAccountNumber
    from ._models_py3 import InvoiceDataBankBSB
    from ._models_py3 import InvoiceDataBankIBAN
    from ._models_py3 import InvoiceDataBankSortCode
    from ._models_py3 import InvoiceDataBankSwift
    from ._models_py3 import InvoiceDataBpayBillerCode
    from ._models_py3 import InvoiceDataBpayReference
    from ._models_py3 import InvoiceDataCustomerBusinessNumber
    from ._models_py3 import InvoiceDataCustomerCompanyName
    from ._models_py3 import InvoiceDataCustomerContactName
    from ._models_py3 import InvoiceDataCustomerEmail
    from ._models_py3 import InvoiceDataCustomerNumber
    from ._models_py3 import InvoiceDataCustomerPhoneNumber
    from ._models_py3 import InvoiceDataCustomerVAT
    from ._models_py3 import InvoiceDataInvoiceNumber
    from ._models_py3 import InvoiceDataInvoicePurchaseOrderNumber
    from ._models_py3 import InvoiceDataPaymentAmountBase
    from ._models_py3 import InvoiceDataPaymentAmountDue
    from ._models_py3 import InvoiceDataPaymentAmountPaid
    from ._models_py3 import InvoiceDataPaymentAmountTax
    from ._models_py3 import InvoiceDataPaymentAmountTotal
    from ._models_py3 import InvoiceDataPaymentReference
    from ._models_py3 import InvoiceDataSupplierBusinessNumber
    from ._models_py3 import InvoiceDataSupplierCompanyName
    from ._models_py3 import InvoiceDataSupplierEmail
    from ._models_py3 import InvoiceDataSupplierFax
    from ._models_py3 import InvoiceDataSupplierPhoneNumber
    from ._models_py3 import InvoiceDataSupplierVAT
    from ._models_py3 import InvoiceDataSupplierWebsite
    from ._models_py3 import InvoiceDataTablesItem
    from ._models_py3 import InvoiceMeta
    from ._models_py3 import JobDescription
    from ._models_py3 import JobDescriptionData
    from ._models_py3 import LanguageAnnotation
    from ._models_py3 import Location
    from ._models_py3 import LocationAnnotation
    from ._models_py3 import Meta
    from ._models_py3 import OccupationGroup
    from ._models_py3 import (
        Paths108CfgmIndexGetResponses200ContentApplicationJsonSchemaPropertiesResultsItems,
    )
    from ._models_py3 import Paths1BwrvmkInvoicesPostRequestbodyContentMultipartFormDataSchema
    from ._models_py3 import Paths1Mc0Je6IndexPostResponses201ContentApplicationJsonSchema
    from ._models_py3 import Paths1UtuacyResumeFormatsGetResponses200ContentApplicationJsonSchema
    from ._models_py3 import Paths1Y6A2MfUsersPostResponses201ContentApplicationJsonSchemaAllof1
    from ._models_py3 import Paths6Pypg5IndexGetResponses200ContentApplicationJsonSchema
    from ._models_py3 import Paths7EskthResumesPostRequestbodyContentMultipartFormDataSchema
    from ._models_py3 import (
        Paths8DdhfcRedactedResumesPostRequestbodyContentMultipartFormDataSchema,
    )
    from ._models_py3 import (
        PathsCoo0XpIndexNameDocumentsPostResponses201ContentApplicationJsonSchema,
    )
    from ._models_py3 import (
        PathsGpptmIndexNameDocumentsPostRequestbodyContentApplicationJsonSchema,
    )
    from ._models_py3 import (
        PathsHryo8IndexNameDocumentsGetResponses200ContentApplicationJsonSchemaPropertiesResultsItems,
    )
    from ._models_py3 import (
        PathsRvverlIndexNameDocumentsGetResponses200ContentApplicationJsonSchema,
    )
    from ._models_py3 import PathsSot11NIndexPostRequestbodyContentMultipartFormDataSchema
    from ._models_py3 import PathsTop5ZkUsersPostResponses201ContentApplicationJsonSchema
    from ._models_py3 import PathsWjaaeuUsersGetResponses200ContentApplicationJsonSchema
    from ._models_py3 import PathsYlw96JobDescriptionsPostRequestbodyContentMultipartFormDataSchema
    from ._models_py3 import (
        PathsYzn84IReformattedResumesPostRequestbodyContentMultipartFormDataSchema,
    )
    from ._models_py3 import Rectangle
    from ._models_py3 import RedactedResume
    from ._models_py3 import RedactedResumeData
    from ._models_py3 import ReformattedResume
    from ._models_py3 import ReformattedResumeData
    from ._models_py3 import RequestError
    from ._models_py3 import RequestErrorErrorsItem
    from ._models_py3 import Resume
    from ._models_py3 import ResumeData
    from ._models_py3 import ResumeDataEducationItem
    from ._models_py3 import ResumeDataEducationItemAccreditation
    from ._models_py3 import ResumeDataEducationItemDates
    from ._models_py3 import ResumeDataEducationItemGrade
    from ._models_py3 import ResumeDataName
    from ._models_py3 import ResumeDataRefereesItem
    from ._models_py3 import ResumeDataSectionsItem
    from ._models_py3 import ResumeDataSkillsItem
    from ._models_py3 import ResumeDataSkillsPropertiesItemsItem
    from ._models_py3 import ResumeDataWorkExperienceItem
    from ._models_py3 import ResumeDataWorkExperienceItemDates
    from ._models_py3 import ResumeDataWorkExperienceItemOccupation
    from ._models_py3 import ResumeSearch
    from ._models_py3 import ResumeSearchDetail
    from ._models_py3 import ResumeSearchDetailEducation
    from ._models_py3 import ResumeSearchDetailEducationMissing
    from ._models_py3 import ResumeSearchDetailEducationValueItem
    from ._models_py3 import ResumeSearchDetailExperience
    from ._models_py3 import ResumeSearchDetailJobTitle
    from ._models_py3 import ResumeSearchDetailJobTitleValueItem
    from ._models_py3 import ResumeSearchDetailLanguages
    from ._models_py3 import ResumeSearchDetailLanguagesValueItem
    from ._models_py3 import ResumeSearchDetailLocation
    from ._models_py3 import ResumeSearchDetailLocationValue
    from ._models_py3 import ResumeSearchDetailManagementLevel
    from ._models_py3 import ResumeSearchDetailOccupationGroup
    from ._models_py3 import ResumeSearchDetailOccupationGroupValueItem
    from ._models_py3 import ResumeSearchDetailSearchExpression
    from ._models_py3 import ResumeSearchDetailSkills
    from ._models_py3 import ResumeSearchDetailSkillsValueItem
    from ._models_py3 import ResumeSearchParameters
    from ._models_py3 import ResumeSearchParametersLocation
    from ._models_py3 import ResumeSearchParametersLocationCoordinates
    from ._models_py3 import ResumeSearchParametersSkill
    from ._models_py3 import ResumeSearchResult
    from ._models_py3 import ResumeSearchScoreComponent
    from ._models_py3 import ResumeSkill
    from ._models_py3 import ResumeSkillSourcesItem
    from ._models_py3 import RowAnnotation
    from ._models_py3 import SkillAnnotation
    from ._models_py3 import TextAnnotation
    from ._models_py3 import User
except (SyntaxError, ImportError):
    from ._models import Accreditation  # type: ignore
    from ._models import Annotation  # type: ignore
    from ._models import Components11Zi81FSchemasInvoicedataPropertiesBankswiftAllof2  # type: ignore
    from ._models import Components14Dm0XSchemasInvoicedataPropertiesBankaccountnumberAllof2  # type: ignore
    from ._models import Components14V23KqSchemasInvoicedataPropertiesPaymentamountdueAllof2  # type: ignore
    from ._models import Components159Ji55SchemasResumesearchdetailPropertiesLanguagesPropertiesValueItemsAllof1  # type: ignore
    from ._models import Components15Ayv0YSchemasInvoicedataPropertiesPaymentamounttotalAllof2  # type: ignore
    from ._models import Components179Pdz6SchemasInvoicedataPropertiesSupplierwebsiteAllof2  # type: ignore
    from ._models import Components17Ashz6SchemasInvoicePropertiesMetaAllof1  # type: ignore
    from ._models import Components1Bh8NlbSchemasInvoicedataPropertiesBpaybillercodeAllof2  # type: ignore
    from ._models import Components1ByjheSchemasInvoicedataPropertiesSupplierfaxAllof2  # type: ignore
    from ._models import Components1Fdmi0OSchemasInvoicedataPropertiesSuppliervatAllof2  # type: ignore
    from ._models import Components1LdfgdeSchemasInvoicedataPropertiesPaymentamountpaidAllof2  # type: ignore
    from ._models import Components1O4BmpySchemasInvoicedataPropertiesSuppliercompanynameAllof2  # type: ignore
    from ._models import Components1OmsnpSchemasInvoicedataPropertiesBpayreferenceAllof2  # type: ignore
    from ._models import Components1Rbm6P1SchemasInvoicedataPropertiesBanksortcodeAllof2  # type: ignore
    from ._models import Components1TryetgSchemasResumedataPropertiesWorkexperienceItemsPropertiesOccupationPropertiesClassification  # type: ignore
    from ._models import Components1Wx56HlSchemasInvoicedataPropertiesPaymentreferenceAllof2  # type: ignore
    from ._models import Components2Hu973SchemasInvoicedataPropertiesCustomernumberAllof2  # type: ignore
    from ._models import Components55Nj82SchemasInvoicedataPropertiesInvoicepurchaseordernumberAllof2  # type: ignore
    from ._models import Components5PwavySchemasInvoicedataPropertiesCustomeremailAllof2  # type: ignore
    from ._models import Components6DhvidSchemasInvoicedataPropertiesCustomercompanynameAllof2  # type: ignore
    from ._models import Components7CqvqpSchemasInvoicedataPropertiesInvoicenumberAllof2  # type: ignore
    from ._models import ComponentsBvthtoSchemasInvoicedataPropertiesSupplierphonenumberAllof2  # type: ignore
    from ._models import ComponentsE6Bjv3SchemasInvoicedataPropertiesBankibanAllof2  # type: ignore
    from ._models import ComponentsH65QjbSchemasResumesearchdetailPropertiesSkillsPropertiesValueItemsAllof1  # type: ignore
    from ._models import ComponentsK7P1F5SchemasResumesearchdetailPropertiesOccupationgroupPropertiesValueItemsAllof1  # type: ignore
    from ._models import ComponentsN9ShogSchemasResumesearchdetailPropertiesLocationPropertiesValueAllof1  # type: ignore
    from ._models import ComponentsPs8Uo7SchemasInvoicedataPropertiesCustomerphonenumberAllof2  # type: ignore
    from ._models import ComponentsRft7JdSchemasInvoicedataPropertiesCustomerbusinessnumberAllof2  # type: ignore
    from ._models import ComponentsRsi73USchemasInvoicedataPropertiesCustomervatAllof2  # type: ignore
    from ._models import ComponentsSxu0N3SchemasResumesearchdetailPropertiesEducationPropertiesValueItemsAllof1  # type: ignore
    from ._models import ComponentsTz04ToSchemasInvoicedataPropertiesPaymentamountbaseAllof2  # type: ignore
    from ._models import ComponentsUilt2MSchemasInvoicedataPropertiesBankbsbAllof2  # type: ignore
    from ._models import ComponentsVyrnzuSchemasInvoicedataPropertiesSupplieremailAllof2  # type: ignore
    from ._models import ComponentsWywi9WSchemasInvoicedataPropertiesCustomercontactnameAllof2  # type: ignore
    from ._models import ComponentsY49P83SchemasInvoicedataPropertiesPaymentamounttaxAllof2  # type: ignore
    from ._models import ComponentsYe0TzySchemasInvoicedataPropertiesSupplierbusinessnumberAllof2  # type: ignore
    from ._models import DateAnnotation  # type: ignore
    from ._models import Education  # type: ignore
    from ._models import EducationDates  # type: ignore
    from ._models import Error  # type: ignore
    from ._models import ExpectedRemunerationAnnotation  # type: ignore
    from ._models import ExpectedRemunerationAnnotationParsed  # type: ignore
    from ._models import Get200ApplicationJsonPropertiesItemsItem  # type: ignore
    from ._models import GetAllDocumentsResults  # type: ignore
    from ._models import GetAllInvoicesResults  # type: ignore
    from ._models import GetAllJobDescriptionsResults  # type: ignore
    from ._models import Invoice  # type: ignore
    from ._models import InvoiceData  # type: ignore
    from ._models import InvoiceDataBankAccountNumber  # type: ignore
    from ._models import InvoiceDataBankBSB  # type: ignore
    from ._models import InvoiceDataBankIBAN  # type: ignore
    from ._models import InvoiceDataBankSortCode  # type: ignore
    from ._models import InvoiceDataBankSwift  # type: ignore
    from ._models import InvoiceDataBpayBillerCode  # type: ignore
    from ._models import InvoiceDataBpayReference  # type: ignore
    from ._models import InvoiceDataCustomerBusinessNumber  # type: ignore
    from ._models import InvoiceDataCustomerCompanyName  # type: ignore
    from ._models import InvoiceDataCustomerContactName  # type: ignore
    from ._models import InvoiceDataCustomerEmail  # type: ignore
    from ._models import InvoiceDataCustomerNumber  # type: ignore
    from ._models import InvoiceDataCustomerPhoneNumber  # type: ignore
    from ._models import InvoiceDataCustomerVAT  # type: ignore
    from ._models import InvoiceDataInvoiceNumber  # type: ignore
    from ._models import InvoiceDataInvoicePurchaseOrderNumber  # type: ignore
    from ._models import InvoiceDataPaymentAmountBase  # type: ignore
    from ._models import InvoiceDataPaymentAmountDue  # type: ignore
    from ._models import InvoiceDataPaymentAmountPaid  # type: ignore
    from ._models import InvoiceDataPaymentAmountTax  # type: ignore
    from ._models import InvoiceDataPaymentAmountTotal  # type: ignore
    from ._models import InvoiceDataPaymentReference  # type: ignore
    from ._models import InvoiceDataSupplierBusinessNumber  # type: ignore
    from ._models import InvoiceDataSupplierCompanyName  # type: ignore
    from ._models import InvoiceDataSupplierEmail  # type: ignore
    from ._models import InvoiceDataSupplierFax  # type: ignore
    from ._models import InvoiceDataSupplierPhoneNumber  # type: ignore
    from ._models import InvoiceDataSupplierVAT  # type: ignore
    from ._models import InvoiceDataSupplierWebsite  # type: ignore
    from ._models import InvoiceDataTablesItem  # type: ignore
    from ._models import InvoiceMeta  # type: ignore
    from ._models import JobDescription  # type: ignore
    from ._models import JobDescriptionData  # type: ignore
    from ._models import LanguageAnnotation  # type: ignore
    from ._models import Location  # type: ignore
    from ._models import LocationAnnotation  # type: ignore
    from ._models import Meta  # type: ignore
    from ._models import OccupationGroup  # type: ignore
    from ._models import Paths108CfgmIndexGetResponses200ContentApplicationJsonSchemaPropertiesResultsItems  # type: ignore
    from ._models import Paths1BwrvmkInvoicesPostRequestbodyContentMultipartFormDataSchema  # type: ignore
    from ._models import Paths1Mc0Je6IndexPostResponses201ContentApplicationJsonSchema  # type: ignore
    from ._models import Paths1UtuacyResumeFormatsGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import Paths1Y6A2MfUsersPostResponses201ContentApplicationJsonSchemaAllof1  # type: ignore
    from ._models import Paths6Pypg5IndexGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import Paths7EskthResumesPostRequestbodyContentMultipartFormDataSchema  # type: ignore
    from ._models import Paths8DdhfcRedactedResumesPostRequestbodyContentMultipartFormDataSchema  # type: ignore
    from ._models import PathsCoo0XpIndexNameDocumentsPostResponses201ContentApplicationJsonSchema  # type: ignore
    from ._models import PathsGpptmIndexNameDocumentsPostRequestbodyContentApplicationJsonSchema  # type: ignore
    from ._models import PathsHryo8IndexNameDocumentsGetResponses200ContentApplicationJsonSchemaPropertiesResultsItems  # type: ignore
    from ._models import PathsRvverlIndexNameDocumentsGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import PathsSot11NIndexPostRequestbodyContentMultipartFormDataSchema  # type: ignore
    from ._models import PathsTop5ZkUsersPostResponses201ContentApplicationJsonSchema  # type: ignore
    from ._models import PathsWjaaeuUsersGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import PathsYlw96JobDescriptionsPostRequestbodyContentMultipartFormDataSchema  # type: ignore
    from ._models import PathsYzn84IReformattedResumesPostRequestbodyContentMultipartFormDataSchema  # type: ignore
    from ._models import Rectangle  # type: ignore
    from ._models import RedactedResume  # type: ignore
    from ._models import RedactedResumeData  # type: ignore
    from ._models import ReformattedResume  # type: ignore
    from ._models import ReformattedResumeData  # type: ignore
    from ._models import RequestError  # type: ignore
    from ._models import RequestErrorErrorsItem  # type: ignore
    from ._models import Resume  # type: ignore
    from ._models import ResumeData  # type: ignore
    from ._models import ResumeDataEducationItem  # type: ignore
    from ._models import ResumeDataEducationItemAccreditation  # type: ignore
    from ._models import ResumeDataEducationItemDates  # type: ignore
    from ._models import ResumeDataEducationItemGrade  # type: ignore
    from ._models import ResumeDataName  # type: ignore
    from ._models import ResumeDataRefereesItem  # type: ignore
    from ._models import ResumeDataSectionsItem  # type: ignore
    from ._models import ResumeDataSkillsItem  # type: ignore
    from ._models import ResumeDataSkillsPropertiesItemsItem  # type: ignore
    from ._models import ResumeDataWorkExperienceItem  # type: ignore
    from ._models import ResumeDataWorkExperienceItemDates  # type: ignore
    from ._models import ResumeDataWorkExperienceItemOccupation  # type: ignore
    from ._models import ResumeSearch  # type: ignore
    from ._models import ResumeSearchDetail  # type: ignore
    from ._models import ResumeSearchDetailEducation  # type: ignore
    from ._models import ResumeSearchDetailEducationMissing  # type: ignore
    from ._models import ResumeSearchDetailEducationValueItem  # type: ignore
    from ._models import ResumeSearchDetailExperience  # type: ignore
    from ._models import ResumeSearchDetailJobTitle  # type: ignore
    from ._models import ResumeSearchDetailJobTitleValueItem  # type: ignore
    from ._models import ResumeSearchDetailLanguages  # type: ignore
    from ._models import ResumeSearchDetailLanguagesValueItem  # type: ignore
    from ._models import ResumeSearchDetailLocation  # type: ignore
    from ._models import ResumeSearchDetailLocationValue  # type: ignore
    from ._models import ResumeSearchDetailManagementLevel  # type: ignore
    from ._models import ResumeSearchDetailOccupationGroup  # type: ignore
    from ._models import ResumeSearchDetailOccupationGroupValueItem  # type: ignore
    from ._models import ResumeSearchDetailSearchExpression  # type: ignore
    from ._models import ResumeSearchDetailSkills  # type: ignore
    from ._models import ResumeSearchDetailSkillsValueItem  # type: ignore
    from ._models import ResumeSearchParameters  # type: ignore
    from ._models import ResumeSearchParametersLocation  # type: ignore
    from ._models import ResumeSearchParametersLocationCoordinates  # type: ignore
    from ._models import ResumeSearchParametersSkill  # type: ignore
    from ._models import ResumeSearchResult  # type: ignore
    from ._models import ResumeSearchScoreComponent  # type: ignore
    from ._models import ResumeSkill  # type: ignore
    from ._models import ResumeSkillSourcesItem  # type: ignore
    from ._models import RowAnnotation  # type: ignore
    from ._models import SkillAnnotation  # type: ignore
    from ._models import TextAnnotation  # type: ignore
    from ._models import User  # type: ignore

from ._affinda_api_enums import (
    EducationLevel,
    ManagementLevel,
    ResumeSkillSourcesItemSection,
    SearchLocationUnit,
)

__all__ = [
    "Accreditation",
    "Annotation",
    "Components11Zi81FSchemasInvoicedataPropertiesBankswiftAllof2",
    "Components14Dm0XSchemasInvoicedataPropertiesBankaccountnumberAllof2",
    "Components14V23KqSchemasInvoicedataPropertiesPaymentamountdueAllof2",
    "Components159Ji55SchemasResumesearchdetailPropertiesLanguagesPropertiesValueItemsAllof1",
    "Components15Ayv0YSchemasInvoicedataPropertiesPaymentamounttotalAllof2",
    "Components179Pdz6SchemasInvoicedataPropertiesSupplierwebsiteAllof2",
    "Components17Ashz6SchemasInvoicePropertiesMetaAllof1",
    "Components1Bh8NlbSchemasInvoicedataPropertiesBpaybillercodeAllof2",
    "Components1ByjheSchemasInvoicedataPropertiesSupplierfaxAllof2",
    "Components1Fdmi0OSchemasInvoicedataPropertiesSuppliervatAllof2",
    "Components1LdfgdeSchemasInvoicedataPropertiesPaymentamountpaidAllof2",
    "Components1O4BmpySchemasInvoicedataPropertiesSuppliercompanynameAllof2",
    "Components1OmsnpSchemasInvoicedataPropertiesBpayreferenceAllof2",
    "Components1Rbm6P1SchemasInvoicedataPropertiesBanksortcodeAllof2",
    "Components1TryetgSchemasResumedataPropertiesWorkexperienceItemsPropertiesOccupationPropertiesClassification",
    "Components1Wx56HlSchemasInvoicedataPropertiesPaymentreferenceAllof2",
    "Components2Hu973SchemasInvoicedataPropertiesCustomernumberAllof2",
    "Components55Nj82SchemasInvoicedataPropertiesInvoicepurchaseordernumberAllof2",
    "Components5PwavySchemasInvoicedataPropertiesCustomeremailAllof2",
    "Components6DhvidSchemasInvoicedataPropertiesCustomercompanynameAllof2",
    "Components7CqvqpSchemasInvoicedataPropertiesInvoicenumberAllof2",
    "ComponentsBvthtoSchemasInvoicedataPropertiesSupplierphonenumberAllof2",
    "ComponentsE6Bjv3SchemasInvoicedataPropertiesBankibanAllof2",
    "ComponentsH65QjbSchemasResumesearchdetailPropertiesSkillsPropertiesValueItemsAllof1",
    "ComponentsK7P1F5SchemasResumesearchdetailPropertiesOccupationgroupPropertiesValueItemsAllof1",
    "ComponentsN9ShogSchemasResumesearchdetailPropertiesLocationPropertiesValueAllof1",
    "ComponentsPs8Uo7SchemasInvoicedataPropertiesCustomerphonenumberAllof2",
    "ComponentsRft7JdSchemasInvoicedataPropertiesCustomerbusinessnumberAllof2",
    "ComponentsRsi73USchemasInvoicedataPropertiesCustomervatAllof2",
    "ComponentsSxu0N3SchemasResumesearchdetailPropertiesEducationPropertiesValueItemsAllof1",
    "ComponentsTz04ToSchemasInvoicedataPropertiesPaymentamountbaseAllof2",
    "ComponentsUilt2MSchemasInvoicedataPropertiesBankbsbAllof2",
    "ComponentsVyrnzuSchemasInvoicedataPropertiesSupplieremailAllof2",
    "ComponentsWywi9WSchemasInvoicedataPropertiesCustomercontactnameAllof2",
    "ComponentsY49P83SchemasInvoicedataPropertiesPaymentamounttaxAllof2",
    "ComponentsYe0TzySchemasInvoicedataPropertiesSupplierbusinessnumberAllof2",
    "DateAnnotation",
    "Education",
    "EducationDates",
    "Error",
    "ExpectedRemunerationAnnotation",
    "ExpectedRemunerationAnnotationParsed",
    "Get200ApplicationJsonPropertiesItemsItem",
    "GetAllDocumentsResults",
    "GetAllInvoicesResults",
    "GetAllJobDescriptionsResults",
    "Invoice",
    "InvoiceData",
    "InvoiceDataBankAccountNumber",
    "InvoiceDataBankBSB",
    "InvoiceDataBankIBAN",
    "InvoiceDataBankSortCode",
    "InvoiceDataBankSwift",
    "InvoiceDataBpayBillerCode",
    "InvoiceDataBpayReference",
    "InvoiceDataCustomerBusinessNumber",
    "InvoiceDataCustomerCompanyName",
    "InvoiceDataCustomerContactName",
    "InvoiceDataCustomerEmail",
    "InvoiceDataCustomerNumber",
    "InvoiceDataCustomerPhoneNumber",
    "InvoiceDataCustomerVAT",
    "InvoiceDataInvoiceNumber",
    "InvoiceDataInvoicePurchaseOrderNumber",
    "InvoiceDataPaymentAmountBase",
    "InvoiceDataPaymentAmountDue",
    "InvoiceDataPaymentAmountPaid",
    "InvoiceDataPaymentAmountTax",
    "InvoiceDataPaymentAmountTotal",
    "InvoiceDataPaymentReference",
    "InvoiceDataSupplierBusinessNumber",
    "InvoiceDataSupplierCompanyName",
    "InvoiceDataSupplierEmail",
    "InvoiceDataSupplierFax",
    "InvoiceDataSupplierPhoneNumber",
    "InvoiceDataSupplierVAT",
    "InvoiceDataSupplierWebsite",
    "InvoiceDataTablesItem",
    "InvoiceMeta",
    "JobDescription",
    "JobDescriptionData",
    "LanguageAnnotation",
    "Location",
    "LocationAnnotation",
    "Meta",
    "OccupationGroup",
    "Paths108CfgmIndexGetResponses200ContentApplicationJsonSchemaPropertiesResultsItems",
    "Paths1BwrvmkInvoicesPostRequestbodyContentMultipartFormDataSchema",
    "Paths1Mc0Je6IndexPostResponses201ContentApplicationJsonSchema",
    "Paths1UtuacyResumeFormatsGetResponses200ContentApplicationJsonSchema",
    "Paths1Y6A2MfUsersPostResponses201ContentApplicationJsonSchemaAllof1",
    "Paths6Pypg5IndexGetResponses200ContentApplicationJsonSchema",
    "Paths7EskthResumesPostRequestbodyContentMultipartFormDataSchema",
    "Paths8DdhfcRedactedResumesPostRequestbodyContentMultipartFormDataSchema",
    "PathsCoo0XpIndexNameDocumentsPostResponses201ContentApplicationJsonSchema",
    "PathsGpptmIndexNameDocumentsPostRequestbodyContentApplicationJsonSchema",
    "PathsHryo8IndexNameDocumentsGetResponses200ContentApplicationJsonSchemaPropertiesResultsItems",
    "PathsRvverlIndexNameDocumentsGetResponses200ContentApplicationJsonSchema",
    "PathsSot11NIndexPostRequestbodyContentMultipartFormDataSchema",
    "PathsTop5ZkUsersPostResponses201ContentApplicationJsonSchema",
    "PathsWjaaeuUsersGetResponses200ContentApplicationJsonSchema",
    "PathsYlw96JobDescriptionsPostRequestbodyContentMultipartFormDataSchema",
    "PathsYzn84IReformattedResumesPostRequestbodyContentMultipartFormDataSchema",
    "Rectangle",
    "RedactedResume",
    "RedactedResumeData",
    "ReformattedResume",
    "ReformattedResumeData",
    "RequestError",
    "RequestErrorErrorsItem",
    "Resume",
    "ResumeData",
    "ResumeDataEducationItem",
    "ResumeDataEducationItemAccreditation",
    "ResumeDataEducationItemDates",
    "ResumeDataEducationItemGrade",
    "ResumeDataName",
    "ResumeDataRefereesItem",
    "ResumeDataSectionsItem",
    "ResumeDataSkillsItem",
    "ResumeDataSkillsPropertiesItemsItem",
    "ResumeDataWorkExperienceItem",
    "ResumeDataWorkExperienceItemDates",
    "ResumeDataWorkExperienceItemOccupation",
    "ResumeSearch",
    "ResumeSearchDetail",
    "ResumeSearchDetailEducation",
    "ResumeSearchDetailEducationMissing",
    "ResumeSearchDetailEducationValueItem",
    "ResumeSearchDetailExperience",
    "ResumeSearchDetailJobTitle",
    "ResumeSearchDetailJobTitleValueItem",
    "ResumeSearchDetailLanguages",
    "ResumeSearchDetailLanguagesValueItem",
    "ResumeSearchDetailLocation",
    "ResumeSearchDetailLocationValue",
    "ResumeSearchDetailManagementLevel",
    "ResumeSearchDetailOccupationGroup",
    "ResumeSearchDetailOccupationGroupValueItem",
    "ResumeSearchDetailSearchExpression",
    "ResumeSearchDetailSkills",
    "ResumeSearchDetailSkillsValueItem",
    "ResumeSearchParameters",
    "ResumeSearchParametersLocation",
    "ResumeSearchParametersLocationCoordinates",
    "ResumeSearchParametersSkill",
    "ResumeSearchResult",
    "ResumeSearchScoreComponent",
    "ResumeSkill",
    "ResumeSkillSourcesItem",
    "RowAnnotation",
    "SkillAnnotation",
    "TextAnnotation",
    "User",
    "EducationLevel",
    "ManagementLevel",
    "ResumeSkillSourcesItemSection",
    "SearchLocationUnit",
]



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator (autorest: 3.8.3, generator: @autorest/python@5.11.2)
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._affinda_api import AffindaAPI

__all__ = ["AffindaAPI"]

# `._patch.py` is used for handwritten extensions to the generated code
# Example: https://github.com/Azure/azure-sdk-for-python/blob/main/doc/dev/customize_code/how-to-patch-sdk-code.md
from ._patch import patch_sdk

patch_sdk()



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator (autorest: 3.8.3, generator: @autorest/python@5.11.2)
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import datetime
import functools
from typing import Any, Callable, Dict, Generic, IO, List, Optional, TypeVar, Union
import warnings

from azure.core.exceptions import (
    ClientAuthenticationError,
    HttpResponseError,
    ResourceExistsError,
    ResourceNotFoundError,
    map_error,
)
from azure.core.pipeline import PipelineResponse
from azure.core.pipeline.transport import AsyncHttpResponse
from azure.core.rest import HttpRequest

from ... import models as _models
from ..._vendor import _convert_request
from ...operations._affinda_api_operations import (
    build_create_index_document_request,
    build_create_index_request,
    build_create_invoice_request,
    build_create_job_description_request,
    build_create_redacted_resume_request,
    build_create_reformatted_resume_request,
    build_create_resume_request,
    build_create_resume_search_request,
    build_create_user_request,
    build_delete_index_document_request,
    build_delete_index_request,
    build_delete_invoice_request,
    build_delete_job_description_request,
    build_delete_redacted_resume_request,
    build_delete_reformatted_resume_request,
    build_delete_resume_request,
    build_get_all_index_documents_request,
    build_get_all_indexes_request,
    build_get_all_invoices_request,
    build_get_all_job_descriptions_request,
    build_get_all_redacted_resumes_request,
    build_get_all_reformatted_resumes_request,
    build_get_all_resume_formats_request,
    build_get_all_resumes_request,
    build_get_all_users_request,
    build_get_invoice_request,
    build_get_job_description_request,
    build_get_redacted_resume_request,
    build_get_reformatted_resume_request,
    build_get_resume_request,
    build_get_resume_search_detail_request,
    build_list_occupation_groups_request,
    build_update_resume_data_request,
)

T = TypeVar("T")
ClsType = Optional[
    Callable[[PipelineResponse[HttpRequest, AsyncHttpResponse], T, Dict[str, Any]], Any]
]


class AffindaAPIOperationsMixin:
    async def get_all_resumes(
        self, **kwargs: Any
    ) -> Union["_models.GetAllDocumentsResults", "_models.RequestError"]:
        """Get list of all resumes.

        Returns all the resume summaries for that user, limited to 300 per page.

        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GetAllDocumentsResults or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.GetAllDocumentsResults or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.GetAllDocumentsResults", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_all_resumes_request(
            offset=self._config.offset,
            limit=self._config.limit,
            template_url=self.get_all_resumes.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("GetAllDocumentsResults", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_all_resumes.metadata = {"url": "/resumes"}  # type: ignore

    async def create_resume(
        self,
        file: Optional[IO] = None,
        url: Optional[str] = None,
        data: Optional["_models.ResumeData"] = None,
        identifier: Optional[str] = None,
        file_name: Optional[str] = None,
        wait: Optional[bool] = True,
        language: Optional[str] = None,
        expiry_time: Optional[datetime.datetime] = None,
        **kwargs: Any,
    ) -> Union["_models.Resume", "_models.RequestError"]:
        """Upload a resume for parsing.

        Uploads a resume for parsing.
        Provide ``file`` for uploading a resume file, or ``url`` for getting resume file from an url,
        or ``data`` if you want to upload resume data directly without parsing any resume file.
        For uploading resume data, the ``data`` argument provided must be a JSON-encoded string.
        When successful, returns an ``identifier`` in the response for subsequent use with the
        `/resumes/{identifier} <#operation/getResume>`_ endpoint to check processing status and
        retrieve results.

        :param file:
        :type file: IO
        :param url:
        :type url: str
        :param data: A JSON-encoded string of the ``ResumeData`` object.
        :type data: ~affinda.models.ResumeData
        :param identifier:
        :type identifier: str
        :param file_name:
        :type file_name: str
        :param wait:
        :type wait: bool
        :param language:
        :type language: str
        :param expiry_time:
        :type expiry_time: ~datetime.datetime
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: Resume or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.Resume or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.Resume", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", None)  # type: Optional[str]

        # Construct form data
        _files = {
            "file": file,
            "url": url,
            "data": data,
            "identifier": identifier,
            "fileName": file_name,
            "wait": wait,
            "language": language,
            "expiryTime": expiry_time,
        }

        request = build_create_resume_request(
            content_type=content_type,
            files=_files,
            template_url=self.create_resume.metadata["url"],
        )
        request = _convert_request(request, _files)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 201, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("Resume", pipeline_response)

        if response.status_code == 201:
            deserialized = self._deserialize("Resume", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_resume.metadata = {"url": "/resumes"}  # type: ignore

    async def get_resume(
        self, identifier: str, **kwargs: Any
    ) -> Union["_models.Resume", "_models.RequestError"]:
        """Get parse results for a specific resume.

        Returns all the parse results for that resume if processing is completed.
        The ``identifier`` is the unique ID returned after POST-ing the resume via the `/resumes
        <#operation/createResume>`_ endpoint.

        :param identifier: Document identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: Resume or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.Resume or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.Resume", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_resume_request(
            identifier=identifier,
            template_url=self.get_resume.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("Resume", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_resume.metadata = {"url": "/resumes/{identifier}"}  # type: ignore

    async def update_resume_data(
        self, identifier: str, body: "_models.ResumeData", **kwargs: Any
    ) -> Union[Optional["_models.ResumeData"], "_models.RequestError"]:
        """Update a resume's data.

        Update data of a parsed resume.
        The ``identifier`` is the unique ID returned after POST-ing the resume via the `/resumes
        <#operation/createResume>`_ endpoint.

        :param identifier: Resume identifier.
        :type identifier: str
        :param body: Resume data to update.
        :type body: ~affinda.models.ResumeData
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: ResumeData or None or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.ResumeData or None or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union[Optional["_models.ResumeData"], "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", "application/json")  # type: Optional[str]

        _json = self._serialize.body(body, "ResumeData")

        request = build_update_resume_data_request(
            identifier=identifier,
            content_type=content_type,
            json=_json,
            template_url=self.update_resume_data.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("ResumeData", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    update_resume_data.metadata = {"url": "/resumes/{identifier}"}  # type: ignore

    async def delete_resume(
        self, identifier: str, **kwargs: Any
    ) -> Optional["_models.RequestError"]:
        """Delete a resume.

        Deletes the specified resume from the database.

        :param identifier: Resume identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: RequestError, or the result of cls(response)
        :rtype: ~affinda.models.RequestError or None
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop("cls", None)  # type: ClsType[Optional["_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_delete_resume_request(
            identifier=identifier,
            template_url=self.delete_resume.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [204, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        deserialized = None
        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    delete_resume.metadata = {"url": "/resumes/{identifier}"}  # type: ignore

    async def get_all_redacted_resumes(
        self, **kwargs: Any
    ) -> Union["_models.GetAllDocumentsResults", "_models.RequestError"]:
        """Get list of all redacted resumes.

        Returns all the redacted resume information for that resume.

        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GetAllDocumentsResults or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.GetAllDocumentsResults or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.GetAllDocumentsResults", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_all_redacted_resumes_request(
            offset=self._config.offset,
            limit=self._config.limit,
            template_url=self.get_all_redacted_resumes.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("GetAllDocumentsResults", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_all_redacted_resumes.metadata = {"url": "/redacted_resumes"}  # type: ignore

    async def create_redacted_resume(
        self,
        file: Optional[IO] = None,
        identifier: Optional[str] = None,
        file_name: Optional[str] = None,
        url: Optional[str] = None,
        language: Optional[str] = None,
        wait: Optional[bool] = True,
        redact_headshot: Optional[bool] = True,
        redact_personal_details: Optional[bool] = True,
        redact_work_details: Optional[bool] = True,
        redact_education_details: Optional[bool] = True,
        redact_referees: Optional[bool] = True,
        redact_locations: Optional[bool] = True,
        redact_dates: Optional[bool] = True,
        redact_gender: Optional[bool] = True,
        expiry_time: Optional[datetime.datetime] = None,
        **kwargs: Any,
    ) -> Union["_models.RedactedResume", "_models.RequestError"]:
        """Upload a resume for redacting.

        Uploads a resume for redacting.

        :param file:
        :type file: IO
        :param identifier:
        :type identifier: str
        :param file_name:
        :type file_name: str
        :param url:
        :type url: str
        :param language:
        :type language: str
        :param wait:
        :type wait: bool
        :param redact_headshot: Whether to redact headshot.
        :type redact_headshot: bool
        :param redact_personal_details: Whether to redact personal details (e.g. name, address).
        :type redact_personal_details: bool
        :param redact_work_details: Whether to redact work details (e.g. company names).
        :type redact_work_details: bool
        :param redact_education_details: Whether to redact education details (e.g. university names).
        :type redact_education_details: bool
        :param redact_referees: Whether to redact referee details.
        :type redact_referees: bool
        :param redact_locations: Whether to redact location names.
        :type redact_locations: bool
        :param redact_dates: Whether to redact dates.
        :type redact_dates: bool
        :param redact_gender: Whether to redact gender.
        :type redact_gender: bool
        :param expiry_time:
        :type expiry_time: ~datetime.datetime
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: RedactedResume or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.RedactedResume or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.RedactedResume", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", None)  # type: Optional[str]

        # Construct form data
        _files = {
            "file": file,
            "identifier": identifier,
            "fileName": file_name,
            "url": url,
            "language": language,
            "wait": wait,
            "redactHeadshot": redact_headshot,
            "redactPersonalDetails": redact_personal_details,
            "redactWorkDetails": redact_work_details,
            "redactEducationDetails": redact_education_details,
            "redactReferees": redact_referees,
            "redactLocations": redact_locations,
            "redactDates": redact_dates,
            "redactGender": redact_gender,
            "expiryTime": expiry_time,
        }

        request = build_create_redacted_resume_request(
            content_type=content_type,
            files=_files,
            template_url=self.create_redacted_resume.metadata["url"],
        )
        request = _convert_request(request, _files)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 201, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("RedactedResume", pipeline_response)

        if response.status_code == 201:
            deserialized = self._deserialize("RedactedResume", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_redacted_resume.metadata = {"url": "/redacted_resumes"}  # type: ignore

    async def get_redacted_resume(
        self, identifier: str, **kwargs: Any
    ) -> Union["_models.RedactedResume", "_models.RequestError"]:
        """Get redaction results for a specific resume.

        Returns all the redaction results for that resume if processing is completed.
        The ``identifier`` is the unique ID returned after POST-ing the resume via the
        `/redacted_resumes <#operation/createRedactedResume>`_ endpoint.

        :param identifier: Document identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: RedactedResume or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.RedactedResume or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.RedactedResume", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_redacted_resume_request(
            identifier=identifier,
            template_url=self.get_redacted_resume.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("RedactedResume", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_redacted_resume.metadata = {"url": "/redacted_resumes/{identifier}"}  # type: ignore

    async def delete_redacted_resume(
        self, identifier: str, **kwargs: Any
    ) -> Optional["_models.RequestError"]:
        """Delete a redacted resume.

        Deletes the specified resume from the database.

        :param identifier: Document identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: RequestError, or the result of cls(response)
        :rtype: ~affinda.models.RequestError or None
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop("cls", None)  # type: ClsType[Optional["_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_delete_redacted_resume_request(
            identifier=identifier,
            template_url=self.delete_redacted_resume.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [204, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        deserialized = None
        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    delete_redacted_resume.metadata = {"url": "/redacted_resumes/{identifier}"}  # type: ignore

    async def get_all_resume_formats(
        self, **kwargs: Any
    ) -> Union[
        "_models.Paths1UtuacyResumeFormatsGetResponses200ContentApplicationJsonSchema",
        "_models.RequestError",
    ]:
        """Get list of all resume formats.

        Returns all the resume formats.

        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: Paths1UtuacyResumeFormatsGetResponses200ContentApplicationJsonSchema or RequestError,
         or the result of cls(response)
        :rtype: ~affinda.models.Paths1UtuacyResumeFormatsGetResponses200ContentApplicationJsonSchema or
         ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.Paths1UtuacyResumeFormatsGetResponses200ContentApplicationJsonSchema", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_all_resume_formats_request(
            offset=self._config.offset,
            limit=self._config.limit,
            template_url=self.get_all_resume_formats.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize(
                "Paths1UtuacyResumeFormatsGetResponses200ContentApplicationJsonSchema",
                pipeline_response,
            )

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_all_resume_formats.metadata = {"url": "/resume_formats"}  # type: ignore

    async def get_all_reformatted_resumes(
        self, **kwargs: Any
    ) -> Union["_models.GetAllDocumentsResults", "_models.RequestError"]:
        """Get list of all reformatted resumes.

        Returns all the reformatted resume information for that resume.

        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GetAllDocumentsResults or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.GetAllDocumentsResults or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.GetAllDocumentsResults", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_all_reformatted_resumes_request(
            offset=self._config.offset,
            limit=self._config.limit,
            template_url=self.get_all_reformatted_resumes.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("GetAllDocumentsResults", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_all_reformatted_resumes.metadata = {"url": "/reformatted_resumes"}  # type: ignore

    async def create_reformatted_resume(
        self,
        resume_format: str,
        file: Optional[IO] = None,
        identifier: Optional[str] = None,
        file_name: Optional[str] = None,
        url: Optional[str] = None,
        language: Optional[str] = None,
        wait: Optional[bool] = True,
        **kwargs: Any,
    ) -> Union["_models.ReformattedResume", "_models.RequestError"]:
        """Upload a resume for reformatting.

        Upload a resume for reformatting.

        :param resume_format:
        :type resume_format: str
        :param file:
        :type file: IO
        :param identifier:
        :type identifier: str
        :param file_name:
        :type file_name: str
        :param url:
        :type url: str
        :param language:
        :type language: str
        :param wait:
        :type wait: bool
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: ReformattedResume or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.ReformattedResume or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.ReformattedResume", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", None)  # type: Optional[str]

        # Construct form data
        _files = {
            "file": file,
            "identifier": identifier,
            "fileName": file_name,
            "url": url,
            "language": language,
            "resumeFormat": resume_format,
            "wait": wait,
        }

        request = build_create_reformatted_resume_request(
            content_type=content_type,
            files=_files,
            template_url=self.create_reformatted_resume.metadata["url"],
        )
        request = _convert_request(request, _files)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 201, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("ReformattedResume", pipeline_response)

        if response.status_code == 201:
            deserialized = self._deserialize("ReformattedResume", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_reformatted_resume.metadata = {"url": "/reformatted_resumes"}  # type: ignore

    async def get_reformatted_resume(
        self, identifier: str, **kwargs: Any
    ) -> Union["_models.ReformattedResume", "_models.RequestError"]:
        """Get reformatting results for a specific resume.

        Returns all the reformatting results for that resume if processing is completed.
        The ``identifier`` is the unique ID returned after POST-ing the resume via the
        `/reformatted_resumes <#operation/createReformattedResume>`_ endpoint.

        :param identifier: Document identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: ReformattedResume or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.ReformattedResume or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.ReformattedResume", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_reformatted_resume_request(
            identifier=identifier,
            template_url=self.get_reformatted_resume.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("ReformattedResume", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_reformatted_resume.metadata = {"url": "/reformatted_resumes/{identifier}"}  # type: ignore

    async def delete_reformatted_resume(
        self, identifier: str, **kwargs: Any
    ) -> Optional["_models.RequestError"]:
        """Delete a reformatted resume.

        Delete the specified resume from the database.

        :param identifier: Document identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: RequestError, or the result of cls(response)
        :rtype: ~affinda.models.RequestError or None
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop("cls", None)  # type: ClsType[Optional["_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_delete_reformatted_resume_request(
            identifier=identifier,
            template_url=self.delete_reformatted_resume.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [204, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        deserialized = None
        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    delete_reformatted_resume.metadata = {"url": "/reformatted_resumes/{identifier}"}  # type: ignore

    async def create_resume_search(
        self, body: "_models.ResumeSearchParameters", **kwargs: Any
    ) -> Union["_models.ResumeSearch", "_models.RequestError"]:
        """Search through parsed resumes.

        Searches through parsed resumes.

        :param body: Search parameters.
        :type body: ~affinda.models.ResumeSearchParameters
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: ResumeSearch or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.ResumeSearch or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.ResumeSearch", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", "application/json")  # type: Optional[str]

        _json = self._serialize.body(body, "ResumeSearchParameters")

        request = build_create_resume_search_request(
            content_type=content_type,
            json=_json,
            offset=self._config.offset,
            limit=self._config.limit,
            template_url=self.create_resume_search.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [201, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 201:
            deserialized = self._deserialize("ResumeSearch", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_resume_search.metadata = {"url": "/resume_search"}  # type: ignore

    async def get_resume_search_detail(
        self, identifier: str, body: "_models.ResumeSearchParameters", **kwargs: Any
    ) -> Union["_models.ResumeSearchDetail", "_models.RequestError"]:
        """Get search result of specific resume.

        This contains more detailed information about the matching score of the search criteria, or
        which search criteria is missing in this resume.
        The ``identifier`` is the unique ID returned via the `/resume_search
        <#operation/createResumeSearch>`_ endpoint.

        :param identifier: Resume identifier.
        :type identifier: str
        :param body: Search parameters.
        :type body: ~affinda.models.ResumeSearchParameters
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: ResumeSearchDetail or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.ResumeSearchDetail or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.ResumeSearchDetail", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", "application/json")  # type: Optional[str]

        _json = self._serialize.body(body, "ResumeSearchParameters")

        request = build_get_resume_search_detail_request(
            identifier=identifier,
            content_type=content_type,
            json=_json,
            template_url=self.get_resume_search_detail.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("ResumeSearchDetail", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_resume_search_detail.metadata = {"url": "/resume_search/details/{identifier}"}  # type: ignore

    async def get_all_job_descriptions(
        self, **kwargs: Any
    ) -> Union["_models.GetAllJobDescriptionsResults", "_models.RequestError"]:
        """Get list of all job descriptions.

        Returns all the job descriptions for that user, limited to 300 per page.

        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GetAllJobDescriptionsResults or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.GetAllJobDescriptionsResults or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.GetAllJobDescriptionsResults", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_all_job_descriptions_request(
            offset=self._config.offset,
            limit=self._config.limit,
            template_url=self.get_all_job_descriptions.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("GetAllJobDescriptionsResults", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_all_job_descriptions.metadata = {"url": "/job_descriptions"}  # type: ignore

    async def create_job_description(
        self,
        file: Optional[IO] = None,
        identifier: Optional[str] = None,
        file_name: Optional[str] = None,
        url: Optional[str] = None,
        wait: Optional[bool] = True,
        language: Optional[str] = None,
        expiry_time: Optional[datetime.datetime] = None,
        **kwargs: Any,
    ) -> Union["_models.JobDescription", "_models.RequestError"]:
        """Upload a job description for parsing.

        Uploads a job description for parsing.
        When successful, returns an ``identifier`` in the response for subsequent use with the
        `/job_descriptions/{identifier} <#operation/getResume>`_ endpoint to check processing status
        and retrieve results.

        :param file:
        :type file: IO
        :param identifier:
        :type identifier: str
        :param file_name:
        :type file_name: str
        :param url:
        :type url: str
        :param wait:
        :type wait: bool
        :param language:
        :type language: str
        :param expiry_time:
        :type expiry_time: ~datetime.datetime
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: JobDescription or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.JobDescription or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.JobDescription", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", None)  # type: Optional[str]

        # Construct form data
        _files = {
            "file": file,
            "identifier": identifier,
            "fileName": file_name,
            "url": url,
            "wait": wait,
            "language": language,
            "expiryTime": expiry_time,
        }

        request = build_create_job_description_request(
            content_type=content_type,
            files=_files,
            template_url=self.create_job_description.metadata["url"],
        )
        request = _convert_request(request, _files)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 201, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("JobDescription", pipeline_response)

        if response.status_code == 201:
            deserialized = self._deserialize("JobDescription", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_job_description.metadata = {"url": "/job_descriptions"}  # type: ignore

    async def get_job_description(
        self, identifier: str, **kwargs: Any
    ) -> Union["_models.JobDescription", "_models.RequestError"]:
        """Get job description results for a specific job description file.

        Returns all the results for that job description if processing is completed.
        The ``identifier`` is the unique ID returned after POST-ing the resume via the
        `/job_descriptions <#operation/createJobDescription>`_ endpoint.

        :param identifier: Document identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: JobDescription or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.JobDescription or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.JobDescription", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_job_description_request(
            identifier=identifier,
            template_url=self.get_job_description.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("JobDescription", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_job_description.metadata = {"url": "/job_descriptions/{identifier}"}  # type: ignore

    async def delete_job_description(
        self, identifier: str, **kwargs: Any
    ) -> Optional["_models.RequestError"]:
        """Delete a job description.

        Deletes the specified job description from the database.

        :param identifier: Document identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: RequestError, or the result of cls(response)
        :rtype: ~affinda.models.RequestError or None
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop("cls", None)  # type: ClsType[Optional["_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_delete_job_description_request(
            identifier=identifier,
            template_url=self.delete_job_description.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [204, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        deserialized = None
        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    delete_job_description.metadata = {"url": "/job_descriptions/{identifier}"}  # type: ignore

    async def get_all_indexes(
        self, **kwargs: Any
    ) -> Union[
        "_models.Paths6Pypg5IndexGetResponses200ContentApplicationJsonSchema",
        "_models.RequestError",
    ]:
        """Get list of all indexes.

        Returns all the indexes.

        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: Paths6Pypg5IndexGetResponses200ContentApplicationJsonSchema or RequestError, or the
         result of cls(response)
        :rtype: ~affinda.models.Paths6Pypg5IndexGetResponses200ContentApplicationJsonSchema or
         ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.Paths6Pypg5IndexGetResponses200ContentApplicationJsonSchema", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_all_indexes_request(
            offset=self._config.offset,
            limit=self._config.limit,
            template_url=self.get_all_indexes.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize(
                "Paths6Pypg5IndexGetResponses200ContentApplicationJsonSchema", pipeline_response
            )

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_all_indexes.metadata = {"url": "/index"}  # type: ignore

    async def create_index(
        self, name: Optional[bool] = True, **kwargs: Any
    ) -> Union[
        "_models.Paths1Mc0Je6IndexPostResponses201ContentApplicationJsonSchema",
        "_models.RequestError",
    ]:
        """Create a new index.

        Create an index for the search tool.

        :param name:
        :type name: bool
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: Paths1Mc0Je6IndexPostResponses201ContentApplicationJsonSchema or RequestError, or the
         result of cls(response)
        :rtype: ~affinda.models.Paths1Mc0Je6IndexPostResponses201ContentApplicationJsonSchema or
         ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.Paths1Mc0Je6IndexPostResponses201ContentApplicationJsonSchema", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", None)  # type: Optional[str]

        # Construct form data
        _files = {
            "name": name,
        }

        request = build_create_index_request(
            content_type=content_type,
            files=_files,
            template_url=self.create_index.metadata["url"],
        )
        request = _convert_request(request, _files)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [201, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 201:
            deserialized = self._deserialize(
                "Paths1Mc0Je6IndexPostResponses201ContentApplicationJsonSchema", pipeline_response
            )

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_index.metadata = {"url": "/index"}  # type: ignore

    async def delete_index(self, name: str, **kwargs: Any) -> Optional["_models.RequestError"]:
        """Delete an index.

        Deletes the specified index from the database.

        :param name: Index name.
        :type name: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: RequestError, or the result of cls(response)
        :rtype: ~affinda.models.RequestError or None
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop("cls", None)  # type: ClsType[Optional["_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_delete_index_request(
            name=name,
            template_url=self.delete_index.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [204, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        deserialized = None
        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    delete_index.metadata = {"url": "/index/{name}"}  # type: ignore

    async def get_all_index_documents(
        self, name: str, **kwargs: Any
    ) -> Union[
        "_models.PathsRvverlIndexNameDocumentsGetResponses200ContentApplicationJsonSchema",
        "_models.RequestError",
    ]:
        """Get indexed documents for a specific index.

        Returns all the indexed documents for that index.

        :param name: Index name.
        :type name: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: PathsRvverlIndexNameDocumentsGetResponses200ContentApplicationJsonSchema or
         RequestError, or the result of cls(response)
        :rtype:
         ~affinda.models.PathsRvverlIndexNameDocumentsGetResponses200ContentApplicationJsonSchema or
         ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.PathsRvverlIndexNameDocumentsGetResponses200ContentApplicationJsonSchema", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_all_index_documents_request(
            name=name,
            template_url=self.get_all_index_documents.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize(
                "PathsRvverlIndexNameDocumentsGetResponses200ContentApplicationJsonSchema",
                pipeline_response,
            )

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_all_index_documents.metadata = {"url": "/index/{name}/documents"}  # type: ignore

    async def create_index_document(
        self,
        name: str,
        body: "_models.PathsGpptmIndexNameDocumentsPostRequestbodyContentApplicationJsonSchema",
        **kwargs: Any,
    ) -> Union[
        "_models.PathsCoo0XpIndexNameDocumentsPostResponses201ContentApplicationJsonSchema",
        "_models.RequestError",
    ]:
        """Index a new document.

        Create an indexed document for the search tool.

        :param name: Index name.
        :type name: str
        :param body: Document to index.
        :type body:
         ~affinda.models.PathsGpptmIndexNameDocumentsPostRequestbodyContentApplicationJsonSchema
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: PathsCoo0XpIndexNameDocumentsPostResponses201ContentApplicationJsonSchema or
         RequestError, or the result of cls(response)
        :rtype:
         ~affinda.models.PathsCoo0XpIndexNameDocumentsPostResponses201ContentApplicationJsonSchema or
         ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.PathsCoo0XpIndexNameDocumentsPostResponses201ContentApplicationJsonSchema", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", "application/json")  # type: Optional[str]

        _json = self._serialize.body(
            body, "PathsGpptmIndexNameDocumentsPostRequestbodyContentApplicationJsonSchema"
        )

        request = build_create_index_document_request(
            name=name,
            content_type=content_type,
            json=_json,
            template_url=self.create_index_document.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [201, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 201:
            deserialized = self._deserialize(
                "PathsCoo0XpIndexNameDocumentsPostResponses201ContentApplicationJsonSchema",
                pipeline_response,
            )

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_index_document.metadata = {"url": "/index/{name}/documents"}  # type: ignore

    async def delete_index_document(
        self, name: str, identifier: str, **kwargs: Any
    ) -> Optional["_models.RequestError"]:
        """Delete an indexed document.

        Delete the specified indexed document from the database.

        :param name: Index name.
        :type name: str
        :param identifier: Document identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: RequestError, or the result of cls(response)
        :rtype: ~affinda.models.RequestError or None
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop("cls", None)  # type: ClsType[Optional["_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_delete_index_document_request(
            name=name,
            identifier=identifier,
            template_url=self.delete_index_document.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [204, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        deserialized = None
        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    delete_index_document.metadata = {"url": "/index/{name}/documents/{identifier}"}  # type: ignore

    async def get_all_invoices(
        self, **kwargs: Any
    ) -> Union["_models.GetAllInvoicesResults", "_models.RequestError"]:
        """Get list of all invoices.

        Returns all the invoice summaries for that user, limited to 300 per page.

        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: GetAllInvoicesResults or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.GetAllInvoicesResults or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.GetAllInvoicesResults", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_all_invoices_request(
            offset=self._config.offset,
            limit=self._config.limit,
            template_url=self.get_all_invoices.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("GetAllInvoicesResults", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_all_invoices.metadata = {"url": "/invoices"}  # type: ignore

    async def create_invoice(
        self,
        file: Optional[IO] = None,
        identifier: Optional[str] = None,
        file_name: Optional[str] = None,
        url: Optional[str] = None,
        wait: Optional[bool] = True,
        language: Optional[str] = None,
        expiry_time: Optional[datetime.datetime] = None,
        **kwargs: Any,
    ) -> Union["_models.Invoice", "_models.RequestError"]:
        """Upload an invoice for parsing.

        Uploads an invoice for parsing.
        When successful, returns an ``identifier`` in the response for subsequent use with the
        `/invoices/{identifier} <#operation/getInvoice>`_ endpoint to check processing status and
        retrieve results.

        :param file:
        :type file: IO
        :param identifier:
        :type identifier: str
        :param file_name:
        :type file_name: str
        :param url:
        :type url: str
        :param wait:
        :type wait: bool
        :param language:
        :type language: str
        :param expiry_time:
        :type expiry_time: ~datetime.datetime
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: Invoice or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.Invoice or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.Invoice", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", None)  # type: Optional[str]

        # Construct form data
        _files = {
            "file": file,
            "identifier": identifier,
            "fileName": file_name,
            "url": url,
            "wait": wait,
            "language": language,
            "expiryTime": expiry_time,
        }

        request = build_create_invoice_request(
            content_type=content_type,
            files=_files,
            template_url=self.create_invoice.metadata["url"],
        )
        request = _convert_request(request, _files)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 201, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("Invoice", pipeline_response)

        if response.status_code == 201:
            deserialized = self._deserialize("Invoice", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_invoice.metadata = {"url": "/invoices"}  # type: ignore

    async def get_invoice(
        self, identifier: str, **kwargs: Any
    ) -> Union["_models.Invoice", "_models.RequestError"]:
        """Get parse results for a specific invoice.

        Returns all the parse results for that invoice if processing is completed.
        The ``identifier`` is the unique ID returned after POST-ing the invoice via the `/invoices
        <#operation/createInvoice>`_ endpoint.

        :param identifier: Document identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: Invoice or RequestError, or the result of cls(response)
        :rtype: ~affinda.models.Invoice or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.Invoice", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_invoice_request(
            identifier=identifier,
            template_url=self.get_invoice.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("Invoice", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_invoice.metadata = {"url": "/invoices/{identifier}"}  # type: ignore

    async def delete_invoice(
        self, identifier: str, **kwargs: Any
    ) -> Optional["_models.RequestError"]:
        """Delete an invoice.

        Delete the specified invoice from the database.

        :param identifier: Invoice identifier.
        :type identifier: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: RequestError, or the result of cls(response)
        :rtype: ~affinda.models.RequestError or None
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop("cls", None)  # type: ClsType[Optional["_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_delete_invoice_request(
            identifier=identifier,
            template_url=self.delete_invoice.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [204, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        deserialized = None
        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    delete_invoice.metadata = {"url": "/invoices/{identifier}"}  # type: ignore

    async def list_occupation_groups(
        self, **kwargs: Any
    ) -> Union[List["_models.OccupationGroup"], "_models.RequestError"]:
        """List occupation groups.

        TODO TODO TODO.

        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: list of OccupationGroup or RequestError, or the result of cls(response)
        :rtype: list[~affinda.models.OccupationGroup] or ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union[List["_models.OccupationGroup"], "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_list_occupation_groups_request(
            template_url=self.list_occupation_groups.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize("[OccupationGroup]", pipeline_response)

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    list_occupation_groups.metadata = {"url": "/occupation_groups"}  # type: ignore

    async def get_all_users(
        self, **kwargs: Any
    ) -> Union[
        "_models.PathsWjaaeuUsersGetResponses200ContentApplicationJsonSchema",
        "_models.RequestError",
    ]:
        """Get list of all users.

        Returns all the users.

        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: PathsWjaaeuUsersGetResponses200ContentApplicationJsonSchema or RequestError, or the
         result of cls(response)
        :rtype: ~affinda.models.PathsWjaaeuUsersGetResponses200ContentApplicationJsonSchema or
         ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.PathsWjaaeuUsersGetResponses200ContentApplicationJsonSchema", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        request = build_get_all_users_request(
            offset=self._config.offset,
            limit=self._config.limit,
            template_url=self.get_all_users.metadata["url"],
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [200, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 200:
            deserialized = self._deserialize(
                "PathsWjaaeuUsersGetResponses200ContentApplicationJsonSchema", pipeline_response
            )

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get_all_users.metadata = {"url": "/users"}  # type: ignore

    async def create_user(
        self,
        username: str,
        id: Optional[int] = None,
        name: Optional[str] = None,
        email: Optional[str] = None,
        **kwargs: Any,
    ) -> Union[
        "_models.PathsTop5ZkUsersPostResponses201ContentApplicationJsonSchema",
        "_models.RequestError",
    ]:
        """Create a new user.

        Create an user as part of your account.

        :param username:
        :type username: str
        :param id:
        :type id: int
        :param name:
        :type name: str
        :param email:
        :type email: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: PathsTop5ZkUsersPostResponses201ContentApplicationJsonSchema or RequestError, or the
         result of cls(response)
        :rtype: ~affinda.models.PathsTop5ZkUsersPostResponses201ContentApplicationJsonSchema or
         ~affinda.models.RequestError
        :raises: ~azure.core.exceptions.HttpResponseError
        """
        cls = kwargs.pop(
            "cls", None
        )  # type: ClsType[Union["_models.PathsTop5ZkUsersPostResponses201ContentApplicationJsonSchema", "_models.RequestError"]]
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
        }
        error_map.update(kwargs.pop("error_map", {}))

        content_type = kwargs.pop("content_type", None)  # type: Optional[str]

        # Construct form data
        _files = {
            "id": id,
            "name": name,
            "username": username,
            "email": email,
        }

        request = build_create_user_request(
            content_type=content_type,
            files=_files,
            template_url=self.create_user.metadata["url"],
        )
        request = _convert_request(request, _files)
        request.url = self._client.format_url(request.url)

        pipeline_response = await self._client._pipeline.run(request, stream=False, **kwargs)
        response = pipeline_response.http_response

        if response.status_code not in [201, 400, 401]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.RequestError, pipeline_response)
            raise HttpResponseError(response=response, model=error)

        if response.status_code == 201:
            deserialized = self._deserialize(
                "PathsTop5ZkUsersPostResponses201ContentApplicationJsonSchema", pipeline_response
            )

        if response.status_code == 400:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if response.status_code == 401:
            deserialized = self._deserialize("RequestError", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_user.metadata = {"url": "/users"}  # type: ignore
